/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM flockIRichDNDService.idl
 */

#ifndef __gen_flockIRichDNDService_h__
#define __gen_flockIRichDNDService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsITransferable_h__
#include "nsITransferable.h"
#endif

#ifndef __gen_nsIDragSession_h__
#include "nsIDragSession.h"
#endif

#ifndef __gen_nsIDOMHTMLTextAreaElement_h__
#include "nsIDOMHTMLTextAreaElement.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    flockIMessage */
#define FLOCKIMESSAGE_IID_STR "a6204395-ab6e-43f0-8bed-29afd826b1e8"

#define FLOCKIMESSAGE_IID \
  {0xa6204395, 0xab6e, 0x43f0, \
    { 0x8b, 0xed, 0x29, 0xaf, 0xd8, 0x26, 0xb1, 0xe8 }}

/**
 * Interface for passing messages ready to be posted or shared via a service
 */
class NS_NO_VTABLE flockIMessage : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(FLOCKIMESSAGE_IID)

  /* attribute AString subject; */
  NS_IMETHOD GetSubject(nsAString & aSubject) = 0;
  NS_IMETHOD SetSubject(const nsAString & aSubject) = 0;

  /* attribute AString body; */
  NS_IMETHOD GetBody(nsAString & aBody) = 0;
  NS_IMETHOD SetBody(const nsAString & aBody) = 0;

  /* attribute AString htmlbody; */
  NS_IMETHOD GetHtmlbody(nsAString & aHtmlbody) = 0;
  NS_IMETHOD SetHtmlbody(const nsAString & aHtmlbody) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_FLOCKIMESSAGE \
  NS_IMETHOD GetSubject(nsAString & aSubject); \
  NS_IMETHOD SetSubject(const nsAString & aSubject); \
  NS_IMETHOD GetBody(nsAString & aBody); \
  NS_IMETHOD SetBody(const nsAString & aBody); \
  NS_IMETHOD GetHtmlbody(nsAString & aHtmlbody); \
  NS_IMETHOD SetHtmlbody(const nsAString & aHtmlbody); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_FLOCKIMESSAGE(_to) \
  NS_IMETHOD GetSubject(nsAString & aSubject) { return _to GetSubject(aSubject); } \
  NS_IMETHOD SetSubject(const nsAString & aSubject) { return _to SetSubject(aSubject); } \
  NS_IMETHOD GetBody(nsAString & aBody) { return _to GetBody(aBody); } \
  NS_IMETHOD SetBody(const nsAString & aBody) { return _to SetBody(aBody); } \
  NS_IMETHOD GetHtmlbody(nsAString & aHtmlbody) { return _to GetHtmlbody(aHtmlbody); } \
  NS_IMETHOD SetHtmlbody(const nsAString & aHtmlbody) { return _to SetHtmlbody(aHtmlbody); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_FLOCKIMESSAGE(_to) \
  NS_IMETHOD GetSubject(nsAString & aSubject) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSubject(aSubject); } \
  NS_IMETHOD SetSubject(const nsAString & aSubject) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSubject(aSubject); } \
  NS_IMETHOD GetBody(nsAString & aBody) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBody(aBody); } \
  NS_IMETHOD SetBody(const nsAString & aBody) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBody(aBody); } \
  NS_IMETHOD GetHtmlbody(nsAString & aHtmlbody) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHtmlbody(aHtmlbody); } \
  NS_IMETHOD SetHtmlbody(const nsAString & aHtmlbody) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetHtmlbody(aHtmlbody); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public flockIMessage
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_FLOCKIMESSAGE

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, flockIMessage)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* attribute AString subject; */
NS_IMETHODIMP _MYCLASS_::GetSubject(nsAString & aSubject)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetSubject(const nsAString & aSubject)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AString body; */
NS_IMETHODIMP _MYCLASS_::GetBody(nsAString & aBody)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetBody(const nsAString & aBody)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AString htmlbody; */
NS_IMETHODIMP _MYCLASS_::GetHtmlbody(nsAString & aHtmlbody)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetHtmlbody(const nsAString & aHtmlbody)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    flockIRichDNDService */
#define FLOCKIRICHDNDSERVICE_IID_STR "584980d2-5d07-42aa-9916-cd404d80e424"

#define FLOCKIRICHDNDSERVICE_IID \
  {0x584980d2, 0x5d07, 0x42aa, \
    { 0x99, 0x16, 0xcd, 0x40, 0x4d, 0x80, 0xe4, 0x24 }}

class NS_NO_VTABLE flockIRichDNDService : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(FLOCKIRICHDNDSERVICE_IID)

  /**
   * Produce a rich nsITransferable from a nsIDragSession. The result
   * is different from what you would get from nsIDragSession.getData(),
   * because we analyse the sourceNode to enrich the resulting
   * nsITransferable. Additional data from the drop may be included to provide
   * more information to the transferable.
   *
   * @param aSession (in) the current drag session
   * @param aDropFlavour (in) the flavour of the drop data
   * @param aDropData (in) the value of the drop data
   * @return a nsITransferable with one or more of the following flavors:
   *         - text/unicode
   *         - text/html
   *         - text/x-moz-url
   *         - text/x-flock-media
   *         - text/x-flock-textcitation
   *         - text/x-flock-htmlcitation
   *
   * text/x-flock-media has the same syntax as text/x-moz-url:
   *    url + "\n" + title
   * we use it to make a distinction with url pointing to webpages, so
   * the caller can treat media data in a different way
   *
   * text/x-flock-{text/html}citation are a represenation of the data
   * plus its source (with title and URL of the source page)
   */
  /* nsITransferable getRichSelection (in nsIDragSession aSession, in AString aDropFlavour, in AString aDropData); */
  NS_IMETHOD GetRichSelection(nsIDragSession *aSession, const nsAString & aDropFlavour, const nsAString & aDropData, nsITransferable **_retval) = 0;

  /**
   * Helper method to extract a flockIMessage from an nsITransferable subject
   * Supports several flavours of transferable data:
   *         - text/unicode
   *         - text/html
   *         - text/x-moz-url
   *         - text/x-flock-media
   *         - text/x-flock-textcitation
   *         - text/x-flock-htmlcitation
   *         - moz/rdfitem
   *
   * @param aSubject (in) a nsITransferable
   * @param aListSize (in) the number of elements in the flavor list array
   * @param aFlavorList (in) an array of desired flavors, in order of
   *                         preference. The message is formatted based on the
   *                         first flavor from the list that is supported by the
   *                         transferable. If none are found, it looks for a
   *                         supported flavor in the transferable.
   * @return a flockIMessage object.
   */
  /* flockIMessage getMessageFromTransferable (in nsITransferable aSubject, in unsigned long aListSize, [array, size_is (aListSize)] in string aFlavorList); */
  NS_IMETHOD GetMessageFromTransferable(nsITransferable *aSubject, PRUint32 aListSize, const char **aFlavorList, flockIMessage **_retval) = 0;

  /**
   * Returns appropriately formatted breadcrumb.
   *
   * @param aType (in) [optional] one of the following:
   *        - plain (default)
   *        - rich
   */
  /* AString getBreadcrumb (in AString aType); */
  NS_IMETHOD GetBreadcrumb(const nsAString & aType, nsAString & _retval) = 0;

  /**
   * Checks if the selection contains rich video content
   *
   * @param aSession (in) the current drag session
   * @return true if the selection contains rich video content
   */
  /* boolean isSelectionRichVideoContent (in nsIDragSession aSession); */
  NS_IMETHOD IsSelectionRichVideoContent(nsIDragSession *aSession, PRBool *_retval) = 0;

  /**
   * Determine the appropriate supported service to handle the rich content drop
   * to an element on the page.
   *
   * @param aSession (in) the drag and drop session
   * @param aTargetElement (in) the target on which we are dropping rich content
   * @return true if the drop was handled
   */
  /* boolean handleDrop (in nsIDragSession aSession, in nsIDOMHTMLElement aTargetElement); */
  NS_IMETHOD HandleDrop(nsIDragSession *aSession, nsIDOMHTMLElement *aTargetElement, PRBool *_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_FLOCKIRICHDNDSERVICE \
  NS_IMETHOD GetRichSelection(nsIDragSession *aSession, const nsAString & aDropFlavour, const nsAString & aDropData, nsITransferable **_retval); \
  NS_IMETHOD GetMessageFromTransferable(nsITransferable *aSubject, PRUint32 aListSize, const char **aFlavorList, flockIMessage **_retval); \
  NS_IMETHOD GetBreadcrumb(const nsAString & aType, nsAString & _retval); \
  NS_IMETHOD IsSelectionRichVideoContent(nsIDragSession *aSession, PRBool *_retval); \
  NS_IMETHOD HandleDrop(nsIDragSession *aSession, nsIDOMHTMLElement *aTargetElement, PRBool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_FLOCKIRICHDNDSERVICE(_to) \
  NS_IMETHOD GetRichSelection(nsIDragSession *aSession, const nsAString & aDropFlavour, const nsAString & aDropData, nsITransferable **_retval) { return _to GetRichSelection(aSession, aDropFlavour, aDropData, _retval); } \
  NS_IMETHOD GetMessageFromTransferable(nsITransferable *aSubject, PRUint32 aListSize, const char **aFlavorList, flockIMessage **_retval) { return _to GetMessageFromTransferable(aSubject, aListSize, aFlavorList, _retval); } \
  NS_IMETHOD GetBreadcrumb(const nsAString & aType, nsAString & _retval) { return _to GetBreadcrumb(aType, _retval); } \
  NS_IMETHOD IsSelectionRichVideoContent(nsIDragSession *aSession, PRBool *_retval) { return _to IsSelectionRichVideoContent(aSession, _retval); } \
  NS_IMETHOD HandleDrop(nsIDragSession *aSession, nsIDOMHTMLElement *aTargetElement, PRBool *_retval) { return _to HandleDrop(aSession, aTargetElement, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_FLOCKIRICHDNDSERVICE(_to) \
  NS_IMETHOD GetRichSelection(nsIDragSession *aSession, const nsAString & aDropFlavour, const nsAString & aDropData, nsITransferable **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRichSelection(aSession, aDropFlavour, aDropData, _retval); } \
  NS_IMETHOD GetMessageFromTransferable(nsITransferable *aSubject, PRUint32 aListSize, const char **aFlavorList, flockIMessage **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMessageFromTransferable(aSubject, aListSize, aFlavorList, _retval); } \
  NS_IMETHOD GetBreadcrumb(const nsAString & aType, nsAString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBreadcrumb(aType, _retval); } \
  NS_IMETHOD IsSelectionRichVideoContent(nsIDragSession *aSession, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->IsSelectionRichVideoContent(aSession, _retval); } \
  NS_IMETHOD HandleDrop(nsIDragSession *aSession, nsIDOMHTMLElement *aTargetElement, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->HandleDrop(aSession, aTargetElement, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public flockIRichDNDService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_FLOCKIRICHDNDSERVICE

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, flockIRichDNDService)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* nsITransferable getRichSelection (in nsIDragSession aSession, in AString aDropFlavour, in AString aDropData); */
NS_IMETHODIMP _MYCLASS_::GetRichSelection(nsIDragSession *aSession, const nsAString & aDropFlavour, const nsAString & aDropData, nsITransferable **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* flockIMessage getMessageFromTransferable (in nsITransferable aSubject, in unsigned long aListSize, [array, size_is (aListSize)] in string aFlavorList); */
NS_IMETHODIMP _MYCLASS_::GetMessageFromTransferable(nsITransferable *aSubject, PRUint32 aListSize, const char **aFlavorList, flockIMessage **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* AString getBreadcrumb (in AString aType); */
NS_IMETHODIMP _MYCLASS_::GetBreadcrumb(const nsAString & aType, nsAString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean isSelectionRichVideoContent (in nsIDragSession aSession); */
NS_IMETHODIMP _MYCLASS_::IsSelectionRichVideoContent(nsIDragSession *aSession, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean handleDrop (in nsIDragSession aSession, in nsIDOMHTMLElement aTargetElement); */
NS_IMETHODIMP _MYCLASS_::HandleDrop(nsIDragSession *aSession, nsIDOMHTMLElement *aTargetElement, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    flockIRichContentDropHandler */
#define FLOCKIRICHCONTENTDROPHANDLER_IID_STR "a04edae3-b463-4402-9ce0-c8e72fa9efd4"

#define FLOCKIRICHCONTENTDROPHANDLER_IID \
  {0xa04edae3, 0xb463, 0x4402, \
    { 0x9c, 0xe0, 0xc8, 0xe7, 0x2f, 0xa9, 0xef, 0xd4 }}

class NS_NO_VTABLE flockIRichContentDropHandler : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(FLOCKIRICHCONTENTDROPHANDLER_IID)

  /**
   * Handle the rich content drop
   * 
   * @param aFlavours (in) use to determine type of content
   * @param aTextarea (in) the TEXTAREA target we are dropping rich content on
   * @return true if the supported service handled the drop
   */
  /* boolean handleDrop (in nsITransferable aFlavours, in nsIDOMHTMLTextAreaElement aTextarea); */
  NS_IMETHOD HandleDrop(nsITransferable *aFlavours, nsIDOMHTMLTextAreaElement *aTextarea, PRBool *_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_FLOCKIRICHCONTENTDROPHANDLER \
  NS_IMETHOD HandleDrop(nsITransferable *aFlavours, nsIDOMHTMLTextAreaElement *aTextarea, PRBool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_FLOCKIRICHCONTENTDROPHANDLER(_to) \
  NS_IMETHOD HandleDrop(nsITransferable *aFlavours, nsIDOMHTMLTextAreaElement *aTextarea, PRBool *_retval) { return _to HandleDrop(aFlavours, aTextarea, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_FLOCKIRICHCONTENTDROPHANDLER(_to) \
  NS_IMETHOD HandleDrop(nsITransferable *aFlavours, nsIDOMHTMLTextAreaElement *aTextarea, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->HandleDrop(aFlavours, aTextarea, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public flockIRichContentDropHandler
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_FLOCKIRICHCONTENTDROPHANDLER

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, flockIRichContentDropHandler)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* boolean handleDrop (in nsITransferable aFlavours, in nsIDOMHTMLTextAreaElement aTextarea); */
NS_IMETHODIMP _MYCLASS_::HandleDrop(nsITransferable *aFlavours, nsIDOMHTMLTextAreaElement *aTextarea, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_flockIRichDNDService_h__ */
